# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/archivematica_tools',
                'doc_host': 'https://nakamura196.github.io',
                'git_url': 'https://github.com/nakamura196/archivematica_tools',
                'lib_path': 'archivematica_tools'},
  'syms': { 'archivematica_tools.api': { 'archivematica_tools.api.ArchivematicaAPIClient': ( 'api.html#archivematicaapiclient',
                                                                                             'archivematica_tools/api.py'),
                                         'archivematica_tools.api.ArchivematicaAPIClient.__init__': ( 'api.html#archivematicaapiclient.__init__',
                                                                                                      'archivematica_tools/api.py'),
                                         'archivematica_tools.api.ArchivematicaAPIClient.approve_transfer': ( 'api.html#archivematicaapiclient.approve_transfer',
                                                                                                              'archivematica_tools/api.py'),
                                         'archivematica_tools.api.ArchivematicaAPIClient.check_transfer_status': ( 'api.html#archivematicaapiclient.check_transfer_status',
                                                                                                                   'archivematica_tools/api.py'),
                                         'archivematica_tools.api.ArchivematicaAPIClient.get_aip_url': ( 'api.html#archivematicaapiclient.get_aip_url',
                                                                                                         'archivematica_tools/api.py'),
                                         'archivematica_tools.api.ArchivematicaAPIClient.get_current_full_path': ( 'api.html#archivematicaapiclient.get_current_full_path',
                                                                                                                   'archivematica_tools/api.py'),
                                         'archivematica_tools.api.ArchivematicaAPIClient.ingest': ( 'api.html#archivematicaapiclient.ingest',
                                                                                                    'archivematica_tools/api.py'),
                                         'archivematica_tools.api.ArchivematicaAPIClient.v2beta_package': ( 'api.html#archivematicaapiclient.v2beta_package',
                                                                                                            'archivematica_tools/api.py')},
            'archivematica_tools.aws': { 'archivematica_tools.aws.AwsClient': ('aws.html#awsclient', 'archivematica_tools/aws.py'),
                                         'archivematica_tools.aws.AwsClient.__init__': ( 'aws.html#awsclient.__init__',
                                                                                         'archivematica_tools/aws.py'),
                                         'archivematica_tools.aws.AwsClient.extract_zip_with_correct_encoding': ( 'aws.html#awsclient.extract_zip_with_correct_encoding',
                                                                                                                  'archivematica_tools/aws.py'),
                                         'archivematica_tools.aws.AwsClient.upload_to_s3': ( 'aws.html#awsclient.upload_to_s3',
                                                                                             'archivematica_tools/aws.py'),
                                         'archivematica_tools.aws.AwsClient.upload_to_s3_zip': ( 'aws.html#awsclient.upload_to_s3_zip',
                                                                                                 'archivematica_tools/aws.py')},
            'archivematica_tools.task': { 'archivematica_tools.task.Task': ('task.html#task', 'archivematica_tools/task.py'),
                                          'archivematica_tools.task.Task.__init__': ( 'task.html#task.__init__',
                                                                                      'archivematica_tools/task.py'),
                                          'archivematica_tools.task.Task.ensure_slash_suffix': ( 'task.html#task.ensure_slash_suffix',
                                                                                                 'archivematica_tools/task.py'),
                                          'archivematica_tools.task.Task.main': ('task.html#task.main', 'archivematica_tools/task.py')}}}
